@@ -1,16 +1,19 @@
 IAPlot <- function(obj, ...){
     UseMethod("IAPlot")
 }
-IAPlot.design <- function(obj, ...){
+IAPlot.design <- function(obj, ..., response=NULL){
     if (!"design" %in% class(obj)) 
         stop("IAPlot.design works for obj from class design only.")
     di <- design.info(obj)
     if (is.null(di$response)) 
         stop("The design obj must have at least one response.")
+    if (!(is.null(response))) 
+      if (!response %in% di$response)
+        stop("Requested response is not a response variable in fit.")
     if (!(length(grep("FrF2",di$type))>0 | 
            length(grep("pb",di$type))>0)) 
         stop("The design obj must be of a type containing FrF2 or pb.")
-    IAPlot(lm(obj, degree=2), ...)
+    IAPlot(lm(obj, degree=2, response=response), ...)
 }
 
 IAPlot.default <-
